Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BasicController ¶
type BasicController struct {
Logger LoggerService
Session *sessions.Session
}
BasicController : Basic Controller
func (*BasicController) AfterActivation ¶
func (c *BasicController) AfterActivation(a mvc.AfterActivation)
AfterActivation : After Activation
func (*BasicController) BeforeActivation ¶
func (c *BasicController) BeforeActivation(b mvc.BeforeActivation)
BeforeActivation : Before Activation
type BasicSubController ¶
BasicSubController : Basic Sub Controller
type PostsController ¶
type PostsController struct {
// context is auto-binded by Iris on each request,
// remember that on each incoming request iris creates a new UserController each time,
// so all fields are request-scoped by-default, only dependency injection is able to set
// custom fields like the Service which is the same for all requests (static binding)
// and the Session which depends on the current context (dynamic binding).
Ctx iris.Context
// Our UserService, it's an interface which
// is binded from the main application.
Service services.PostService
// Session, binded using dependency injection from the main.go.
Session *sessions.Session
}
func (*PostsController) Get ¶
func (c *PostsController) Get() string
func (*PostsController) GetAll ¶
func (c *PostsController) GetAll() string
func (*PostsController) GetOne ¶
func (c *PostsController) GetOne() *json.JsonResult
type UserController ¶
type UserController struct {
// context is auto-binded by Iris on each request,
// remember that on each incoming request iris creates a new UserController each time,
// so all fields are request-scoped by-default, only dependency injection is able to set
// custom fields like the Service which is the same for all requests (static binding)
// and the Session which depends on the current context (dynamic binding).
Ctx iris.Context
// Our UserService, it's an interface which
// is binded from the main application.
Service services.UserService
// Session, binded using dependency injection from the main.go.
Session *sessions.Session
}
func (*UserController) Get ¶
func (c *UserController) Get() string
func (*UserController) GetAll ¶
func (c *UserController) GetAll() string
func (*UserController) GetLogin ¶
func (c *UserController) GetLogin() *json.JsonResult
func (*UserController) GetOne ¶
func (c *UserController) GetOne() *json.JsonResult
Click to show internal directories.
Click to hide internal directories.